@echo off
set now_path = %~f0
set version = 3.1.3
echo from color_text import output_example > color_text-example.py
echo output_example(time_to_sleep = 0) >> color_text-example.py
echo color_text example
echo color_text Àý×Ó
python color_text-example.py
pause
